@@ -2,12 +2,11 @@ import json
 import os
 import tempfile
 import unittest
-from re import sub
+from difflib import SequenceMatcher
 
 import numpy as np
 import pandas
 import PIL
-from pydub import AudioSegment
 
 import gradio as gr
 
@@ -124,8 +123,9 @@ class TestTextbox(unittest.TestCase):
 
 class TestNumber(unittest.TestCase):
     def test_as_component(self):
-        numeric_input = gr.inputs.Number()
+        numeric_input = gr.inputs.Number(optional=True)
         self.assertEqual(numeric_input.preprocess(3), 3.0)
+        self.assertEqual(numeric_input.preprocess(None), None)
         self.assertEqual(numeric_input.preprocess_example(3), 3)
         self.assertEqual(numeric_input.serialize(3, True), 3)
         with tempfile.TemporaryDirectory() as tmpdirname:
@@ -144,12 +144,16 @@ class TestNumber(unittest.TestCase):
             numeric_input.get_interpretation_neighbors(1),
             ([0.97, 0.98, 0.99, 1.01, 1.02, 1.03], {}),
         )
+        self.assertEqual(
+            numeric_input.get_template_context(),
+            {"default": None, "optional": True, "name": "number", "label": None},
+        )
 
     def test_in_interface(self):
-        iface = gr.Interface(lambda x: x ** 2, "number", "textbox")
+        iface = gr.Interface(lambda x: x**2, "number", "textbox")
         self.assertEqual(iface.process([2])[0], ["4.0"])
         iface = gr.Interface(
-            lambda x: x ** 2, "number", "textbox", interpretation="default"
+            lambda x: x**2, "number", "textbox", interpretation="default"
         )
         scores, alternative_outputs = iface.interpret([2])
         self.assertEqual(
@@ -205,15 +209,16 @@ class TestSlider(unittest.TestCase):
                 "step": 1,
                 "default": 15,
                 "name": "slider",
+                "optional": False,
                 "label": "Slide Your Input",
             },
         )
 
     def test_in_interface(self):
-        iface = gr.Interface(lambda x: x ** 2, "slider", "textbox")
+        iface = gr.Interface(lambda x: x**2, "slider", "textbox")
         self.assertEqual(iface.process([2])[0], ["4"])
         iface = gr.Interface(
-            lambda x: x ** 2, "slider", "textbox", interpretation="default"
+            lambda x: x**2, "slider", "textbox", interpretation="default"
         )
         scores, alternative_outputs = iface.interpret([2])
         self.assertEqual(
@@ -263,7 +268,12 @@ class TestCheckbox(unittest.TestCase):
         bool_input = gr.inputs.Checkbox(default=True, label="Check Your Input")
         self.assertEqual(
             bool_input.get_template_context(),
-            {"default": True, "name": "checkbox", "label": "Check Your Input"},
+            {
+                "default": True,
+                "name": "checkbox",
+                "optional": False,
+                "label": "Check Your Input",
+            },
         )
 
     def test_in_interface(self):
@@ -302,6 +312,7 @@ class TestCheckboxGroup(unittest.TestCase):
             {
                 "choices": ["a", "b", "c"],
                 "default": ["a", "c"],
+                "optional": False,
                 "name": "checkboxgroup",
                 "label": "Check Your Inputs",
             },
@@ -350,6 +361,7 @@ class TestRadio(unittest.TestCase):
                 "default": "a",
                 "name": "radio",
                 "label": "Pick Your One Input",
+                "optional": False,
             },
         )
         with self.assertRaises(ValueError):
@@ -394,6 +406,7 @@ class TestDropdown(unittest.TestCase):
                 "default": "a",
                 "name": "dropdown",
                 "label": "Drop Your Input",
+                "optional": False,
             },
         )
         with self.assertRaises(ValueError):
@@ -565,21 +578,14 @@ class TestAudio(unittest.TestCase):
         x_wav = gr.processing_utils.audio_from_file("test/test_files/audio_sample.wav")
         self.assertIsInstance(audio_input.serialize(x_wav, False), dict)
 
-    # def test_in_interface(self):
-    #     x_wav = gr.test_data.BASE64_AUDIO
-    #     def max_amplitude_from_wav_file(wav_file):
-    #         audio_segment = AudioSegment.from_file(wav_file.name)
-    #         data = np.array(audio_segment.get_array_of_samples())
-    #         return np.max(data)
-    #     iface = gr.Interface(
-    #         max_amplitude_from_wav_file,
-    #         gr.inputs.Audio(type="file"),
-    #         "number", interpretation="default")
-    # # TODO(aliabd): investigate why this sometimes fails (returns 5239 or 576)
-    #     self.assertEqual(iface.process([x_wav])[0], [576])
-    #     scores, alternative_outputs = iface.interpret([x_wav])
-    #     self.assertEqual(scores, ... )
-    #     self.assertEqual(alternative_outputs, ...)
+    def test_tokenize(self):
+        x_wav = gr.test_data.BASE64_AUDIO
+        audio_input = gr.inputs.Audio()
+        tokens, _, _ = audio_input.tokenize(x_wav)
+        self.assertEquals(len(tokens), audio_input.interpretation_segments)
+        x_new = audio_input.get_masked_inputs(tokens, [[1] * len(tokens)])[0]
+        similarity = SequenceMatcher(a=x_wav["data"], b=x_new).ratio()
+        self.assertGreater(similarity, 0.9)
 
 
 class TestFile(unittest.TestCase):
@@ -659,6 +665,7 @@ class TestDataframe(unittest.TestCase):
                 "default": [[None, None, None], [None, None, None], [None, None, None]],
                 "name": "dataframe",
                 "label": "Dataframe Input",
+                "optional": False,
             },
         )
         dataframe_input = gr.inputs.Dataframe()
@@ -674,8 +681,8 @@ class TestDataframe(unittest.TestCase):
         self.assertEqual(iface.process([x_data])[0], [6])
         x_data = [["Tim"], ["Jon"], ["Sal"]]
 
-        def get_last(l):
-            return l[-1]
+        def get_last(my_list):
+            return my_list[-1]
 
         iface = gr.Interface(get_last, "list", "text")
         self.assertEqual(iface.process([x_data])[0], ["Sal"])
